@@ -93,7 +93,7 @@ def handle_robot_options(
         sys.path = old_sys_path
 
     config_files, root_folder, _ = get_config_files(
-        robot_arguments, app.config.config_files, raise_on_error=False, verbose_callback=app.verbose
+        robot_arguments, app.config.config_files, verbose_callback=app.verbose
     )
     try:
         profile = (
